import 'package:flutter/material.dart';
import 'package:vivanta_connect_example/vivanta.dart';
import 'package:vivanta_connect_flutter/services/http.dart';
import 'package:vivanta_connect_flutter/vivanta_connect_flutter.dart';

Future<Object?> launchVivantaConnectWithKeys(
  BuildContext context,
  String externalUserId,
  String? companyId,
) async {
  return Navigator.of(context).push(
    MaterialPageRoute(
      builder: (context) => VivantaConnectFlutter(
        apiKey: Vivanta.apiKey,
        customerId: Vivanta.customerId,
        externalUserId: externalUserId,
        companyId: companyId,
      ),
    ),
  );
}

Future<Object?> launchVivantaConnectWithToken(
    BuildContext context, String token) async {
  return Navigator.of(context).push(
    MaterialPageRoute(
      builder: (context) => VivantaConnectFlutter(
        token: token,
      ),
    ),
  );
}

Future<String> getToken(String externalUserId, String companyId) async {
  final http = Http();
  final user = await http.authenticateUser(
    Vivanta.apiKey,
    Vivanta.customerId,
    externalUserId,
    companyId,
  );
  if (user != null) {
    if (user.token != null) {
      return user.token!;
    }
  }
  return '';
}

Future<void> showSyncSuccess(BuildContext context) async {
  return showModalBottomSheet(
    context: context,
    builder: (context) {
      return Container(
        height: 100,
        child: Center(
          child: Column(
            mainAxisAlignment: MainAxisAlignment.center,
            mainAxisSize: MainAxisSize.min,
            children: <Widget>[
              const Text('Data sync finished successfully'),
              SizedBox(
                height: 8,
              ),
              ElevatedButton(
                child: const Text('Close'),
                onPressed: () => Navigator.pop(context),
              ),
              SizedBox(
                height: 8,
              ),
            ],
          ),
        ),
      );
    },
  );
}
