import 'package:vivanta_connect_example/vivanta.dart';
import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:vivanta_connect_flutter/enums/apple_health_parameter_type.dart';
import 'package:vivanta_connect_flutter/helpers/vivanta_sync.dart';

class AppleHealthParameterSelection {
  final AppleHealthParameterType parameterType;
  final double value;

  AppleHealthParameterSelection(this.parameterType, this.value);
}

class SelectAppleHealthParameterType extends StatefulWidget {
  const SelectAppleHealthParameterType({Key? key}) : super(key: key);

  @override
  State<SelectAppleHealthParameterType> createState() =>
      _SelectAppleHealthParameterTypeState();
}

class _SelectAppleHealthParameterTypeState
    extends State<SelectAppleHealthParameterType> {
  late TextEditingController _valueController;
  List<AppleHealthParameterType> _parameterTypes = [];

  @override
  void initState() {
    super.initState();
    _init();
    _valueController = TextEditingController(text: '1');
  }

  @override
  void dispose() {
    _valueController.dispose();
    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(title: const Text('Select Apple Health Parameter Type')),
      body: Column(
        mainAxisAlignment: MainAxisAlignment.spaceBetween,
        children: [
          Padding(
            padding: const EdgeInsets.all(16),
            child: TextField(
              decoration: new InputDecoration(
                labelText: 'Enter the value to write',
              ),
              keyboardType: TextInputType.number,
              inputFormatters: <TextInputFormatter>[
                FilteringTextInputFormatter.digitsOnly
              ],
              controller: _valueController,
              onEditingComplete: () {
                FocusScope.of(context).unfocus();
              },
            ),
          ),
          Expanded(
            child: ListView.builder(
              itemBuilder: ((context, index) {
                final parameterType = _parameterTypes[index];
                return ListTile(
                  title: Text(parameterType.name),
                  onTap: () {
                    Navigator.pop(
                      context,
                      AppleHealthParameterSelection(
                        parameterType,
                        _valueController.text.isEmpty
                            ? 1
                            : double.parse(_valueController.text),
                      ),
                    );
                  },
                );
              }),
              itemCount: _parameterTypes.length,
            ),
          ),
        ],
      ),
    );
  }

  void _init() {
    final vivanta = VivantaSync(
      apiKey: Vivanta.apiKey,
      customerId: Vivanta.customerId,
      externalUserId: '',
    );

    vivanta.getAppleHealthWritePermissions().then((value) => setState(() {
          _parameterTypes = value;
          _parameterTypes.sort((a, b) => a.name.compareTo(b.name));
        }));
  }
}
