import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:vivanta_connect_flutter/enums/google_health_activity_type.dart';

class GoogleHealthActivitySelection {
  final GoogleHealthActivityType activityType;
  final int duration;
  final int? distance;
  final int? calories;

  GoogleHealthActivitySelection(
    this.activityType,
    this.duration,
    this.distance,
    this.calories,
  );
}

class SelectGoogleHealthActivityType extends StatefulWidget {
  const SelectGoogleHealthActivityType({Key? key}) : super(key: key);

  @override
  State<SelectGoogleHealthActivityType> createState() =>
      _SelectGoogleHealthActivityTypeState();
}

class _SelectGoogleHealthActivityTypeState
    extends State<SelectGoogleHealthActivityType> {
  late TextEditingController _durationController;
  late TextEditingController _caloriesController;
  late TextEditingController _distanceController;
  late List<GoogleHealthActivityType> _activityTypes = [];

  @override
  void initState() {
    super.initState();
    _durationController = TextEditingController(text: '1');
    _caloriesController = TextEditingController(text: '0');
    _distanceController = TextEditingController(text: '0');
    _activityTypes = GoogleHealthActivityType.values;
    //_activityTypes.sort((a, b) => a.name.compareTo(b.name));
  }

  @override
  void dispose() {
    _caloriesController.dispose();
    _distanceController.dispose();
    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(title: const Text('Select Google Health Activity Type')),
      body: Column(
        mainAxisAlignment: MainAxisAlignment.spaceBetween,
        children: [
          Padding(
            padding: const EdgeInsets.all(16),
            child: TextField(
              decoration: new InputDecoration(
                labelText: 'Enter the duration of the activity in seconds',
              ),
              keyboardType: TextInputType.number,
              inputFormatters: <TextInputFormatter>[
                FilteringTextInputFormatter.digitsOnly
              ],
              controller: _durationController,
              onEditingComplete: () {
                FocusScope.of(context).unfocus();
              },
            ),
          ),
          Padding(
            padding: const EdgeInsets.all(16),
            child: TextField(
              decoration: new InputDecoration(
                labelText: 'Enter the distance in meters',
              ),
              keyboardType: TextInputType.number,
              inputFormatters: <TextInputFormatter>[
                FilteringTextInputFormatter.digitsOnly
              ],
              controller: _distanceController,
              onEditingComplete: () {
                FocusScope.of(context).unfocus();
              },
            ),
          ),
          Padding(
            padding: const EdgeInsets.all(16),
            child: TextField(
              decoration: new InputDecoration(
                labelText: 'Enter the calories consumed',
              ),
              keyboardType: TextInputType.number,
              inputFormatters: <TextInputFormatter>[
                FilteringTextInputFormatter.digitsOnly
              ],
              controller: _caloriesController,
              onEditingComplete: () {
                FocusScope.of(context).unfocus();
              },
            ),
          ),
          Expanded(
            child: ListView.builder(
              itemBuilder: ((context, index) {
                final activity = _activityTypes[index];
                return ListTile(
                  title: Text(activity.name),
                  onTap: () {
                    Navigator.pop(
                      context,
                      GoogleHealthActivitySelection(
                        activity,
                        _durationController.text.isEmpty
                            ? 1
                            : int.parse(_durationController.text),
                        _distanceController.text.isEmpty
                            ? null
                            : int.parse(_distanceController.text),
                        _caloriesController.text.isEmpty
                            ? null
                            : int.parse(_caloriesController.text),
                      ),
                    );
                  },
                );
              }),
              itemCount: _activityTypes.length,
            ),
          ),
        ],
      ),
    );
  }
}
