import 'package:health/health.dart';

import 'package:vivanta_connect_flutter/data/apple_category_type_client.dart';
import 'package:vivanta_connect_flutter/data/apple_quantity_type_client.dart';
import 'package:vivanta_connect_flutter/data/client.dart';
import 'package:vivanta_connect_flutter/data/google_parameter_type_client.dart';

class HealthPermission {
  final HealthDataType healthDataType;
  final HealthDataAccess healthDataAccess;

  const HealthPermission({
    required this.healthDataType,
    required this.healthDataAccess,
  });
}

convertAppleHealthTimestampToDateTime(num timestamp) {
  final newTimestamp = timestamp * 1000;
  return DateTime.fromMillisecondsSinceEpoch(
      int.parse(newTimestamp.toString().split('.')[0]));
}

List<HealthPermission> getHealthPermissionsFromClient(Client? client) {
  return [
    ...getAppleHealthPermissionFromClient(client),
    ...getGoogleHealthPermissionFromClient(client),
  ];
}

List<HealthPermission> getAppleHealthPermissionFromClient(Client? client) {
  final quantityTypes = client?.appleQuantityTypeClient ?? [];

  final categoryTypes = client?.appleCategoryTypeClient ?? [];

  return getHealthPermissionsFromApi(quantityTypes, categoryTypes, []);
}

List<HealthPermission> getGoogleHealthPermissionFromClient(Client? client) {
  final parameterTypes = client?.googleParameterTypeClient ?? [];

  return getHealthPermissionsFromApi([], [], parameterTypes);
}

List<HealthPermission> getHealthPermissionsFromApi(
    List<AppleQuantityTypeClient?> quantityTypes,
    List<AppleCategoryTypeClient?> categoryTypes,
    List<GoogleParameterTypeClient?> parameterTypes) {
  return [
    ...covertQuantityTypesToHealthDataType(quantityTypes),
    ...covertCategoryTypesToHealthDataType(categoryTypes),
    ...convertParameterTypesToHealthDataType(parameterTypes),
  ];
}

List<HealthPermission> covertQuantityTypesToHealthDataType(
    List<AppleQuantityTypeClient?> quantityTypes) {
  final List<HealthPermission> healthPermissions = [];
  for (AppleQuantityTypeClient? element in quantityTypes) {
    for (HealthDataType healthDataType in HealthDataType.values) {
      if (healthDataType.name == element?.appleQuantityType?.quantityType) {
        healthPermissions.add(
          HealthPermission(
            healthDataType: healthDataType,
            healthDataAccess: getHealthDataAccessFromString(
              element?.permissionType,
            ),
          ),
        );
      }
    }
  }

  return healthPermissions;
}

List<HealthPermission> covertCategoryTypesToHealthDataType(
    List<AppleCategoryTypeClient?> categoryTypes) {
  final List<HealthPermission> healthPermissions = [];
  for (AppleCategoryTypeClient? element in categoryTypes) {
    for (HealthDataType healthDataType in HealthDataType.values) {
      if (healthDataType.name == element?.appleCategoryType?.categoryType) {
        healthPermissions.add(
          HealthPermission(
            healthDataType: healthDataType,
            healthDataAccess: getHealthDataAccessFromString(
              element?.permissionType,
            ),
          ),
        );
      }
    }
  }

  return healthPermissions;
}

List<HealthPermission> convertParameterTypesToHealthDataType(
    List<GoogleParameterTypeClient?> parameterTypes) {
  final List<HealthPermission> healthPermissions = [];
  for (GoogleParameterTypeClient? element in parameterTypes) {
    for (HealthDataType healthDataType in HealthDataType.values) {
      if (healthDataType.name == element?.googleParameterType?.parameterType) {
        healthPermissions.add(
          HealthPermission(
            healthDataType: healthDataType,
            healthDataAccess: getHealthDataAccessFromString(
              element?.permissionType,
            ),
          ),
        );
      }
    }
  }
  return healthPermissions;
}

HealthDataAccess getHealthDataAccessFromString(String? permissionType) {
  switch (permissionType) {
    case 'write':
      return HealthDataAccess.WRITE;
    case 'read_write':
      return HealthDataAccess.READ_WRITE;
    default:
      return HealthDataAccess.READ;
  }
}
