import 'package:hive_flutter/hive_flutter.dart';

import 'package:vivanta_connect_flutter/models/apple_health_element.dart';
import 'package:vivanta_connect_flutter/models/google_health_connect_element.dart';

class Database {
  Box<AppleHealthElement>? appleHealthElementBox;
  Box<GoogleHealthConnectElement>? googleHealthConnectElementBox;

  init() async {
    await Hive.initFlutter();
    if (!Hive.isAdapterRegistered(0)) {
      Hive.registerAdapter(AppleHealthElementAdapter());
    }
    if (!Hive.isAdapterRegistered(1)) {
      Hive.registerAdapter(GoogleHealthConnectElementAdapter());
    }
    appleHealthElementBox =
        await Hive.openBox<AppleHealthElement>('apple_heealth_elements');
    googleHealthConnectElementBox =
        await Hive.openBox<GoogleHealthConnectElement>(
            'google_health_connect_elements');
  }

  Future<AppleHealthElement?> getAppleHealthElement(String id) async {
    try {
      return appleHealthElementBox!.values
          .firstWhere((element) => element.id == id);
    } catch (_) {}
    return null;
  }

  Future<int> saveAppleHealthElement(AppleHealthElement element) {
    return appleHealthElementBox!.add(element);
  }

  Future<void> updateAppleHealthElement(AppleHealthElement element) {
    return appleHealthElementBox!.put(element.key, element);
  }

  List<AppleHealthElement> getUnsyncedAppleHealthElements() {
    return appleHealthElementBox!.values
        .where((element) => element.synced == false)
        .toList();
  }

  List<AppleHealthElement> getOldSyncedAppleHealthElements() {
    final todayMinusSevenDays =
        DateTime.now().subtract(const Duration(days: 7));
    return appleHealthElementBox!.values.where((element) {
      final date = DateTime.tryParse(element.syncedDate ?? '');
      if (date == null) return true;
      return (element.synced ?? false) && date.isBefore(todayMinusSevenDays);
    }).toList();
  }

  void deleteAppleHealthElement(AppleHealthElement element) {
    element.delete();
  }

  Future<GoogleHealthConnectElement?> getGoogleHealthConnectElement(
      String id) async {
    try {
      return googleHealthConnectElementBox!.values
          .firstWhere((element) => element.id == id);
    } catch (_) {}
    return null;
  }

  Future<int> saveGoogleHealthConnectElement(
      GoogleHealthConnectElement element) {
    return googleHealthConnectElementBox!.add(element);
  }

  Future<void> updateGoogleHealthConnectElement(
      GoogleHealthConnectElement element) {
    return googleHealthConnectElementBox!.put(element.key, element);
  }

  List<GoogleHealthConnectElement> getUnsyncedGoogleHealthConnectElements() {
    return googleHealthConnectElementBox!.values
        .where((element) => element.synced == false)
        .toList();
  }

  List<GoogleHealthConnectElement> getOldSyncedGoogleHealthConnectElements() {
    final todayMinusSevenDays =
        DateTime.now().subtract(const Duration(days: 7));
    return googleHealthConnectElementBox!.values.where((element) {
      final date = DateTime.tryParse(element.syncedDate ?? '');
      if (date == null) return true;
      return (element.synced ?? false) && date.isBefore(todayMinusSevenDays);
    }).toList();
  }

  void deleteGoogleHealthConnectElement(GoogleHealthConnectElement element) {
    element.delete();
  }
}
