import 'package:flutter/material.dart';

import 'package:webview_flutter/webview_flutter.dart';

import 'package:vivanta_connect_flutter/styles/colors.dart';
import 'package:vivanta_connect_flutter/views/loading.dart';

class Privacy extends StatefulWidget {
  const Privacy({Key? key}) : super(key: key);

  @override
  State<Privacy> createState() => _PrivacyState();
}

class _PrivacyState extends State<Privacy> {
  late WebViewController _controller;
  bool _loading = false;

  @override
  void initState() {
    _controller = WebViewController()
      ..setJavaScriptMode(JavaScriptMode.unrestricted)
      ..clearLocalStorage()
      ..setBackgroundColor(VivantaColors.background)
      ..setNavigationDelegate(NavigationDelegate(
        onProgress: (progress) {
          setState(() {
            _loading = progress < 100;
          });
        },
        onPageStarted: (url) {},
        onPageFinished: (url) {
          setState(() {
            _loading = false;
          });
        },
        onWebResourceError: (WebResourceError error) {},
        onNavigationRequest: (NavigationRequest request) {
          return NavigationDecision.navigate;
        },
      ))
      ..loadRequest(Uri.parse('https://connect.vivanta.io/privacy'));
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    return _loading
        ? const Loading()
        : Scaffold(
            backgroundColor: VivantaColors.background,
            appBar: AppBar(
              backgroundColor: VivantaColors.background,
              elevation: 0,
              title: const Center(
                child: Image(
                  image: AssetImage(
                    "images/vivanta-logo.png",
                    package: 'vivanta_connect_flutter',
                  ),
                  height: 20,
                  fit: BoxFit.cover,
                ),
              ),
              leading: GestureDetector(
                onTap: () {
                  Navigator.of(context).maybePop();
                },
                child: const Icon(
                  Icons.arrow_back_ios,
                  color: VivantaColors.text,
                  size: 24,
                ),
              ),
              actions: [
                Padding(
                  padding: const EdgeInsets.only(right: 16),
                  child: GestureDetector(
                    onTap: () {
                      Navigator.of(context).pushReplacementNamed('/close');
                    },
                    child: const Icon(
                      Icons.close,
                      color: VivantaColors.text,
                      size: 24,
                    ),
                  ),
                ),
              ],
            ),
            body: Column(
              children: [
                Expanded(
                  child: WebViewWidget(
                    controller: _controller,
                  ),
                ),
              ],
            ),
          );
  }
}
