import 'package:flutter/gestures.dart';
import 'package:flutter/material.dart';

import 'package:flutter_i18n/flutter_i18n.dart';

import 'package:vivanta_connect_flutter/data/client.dart';
import 'package:vivanta_connect_flutter/services/http.dart';
import 'package:vivanta_connect_flutter/services/preferences.dart';
import 'package:vivanta_connect_flutter/styles/colors.dart';
import 'package:vivanta_connect_flutter/styles/fonts.dart';
import 'package:vivanta_connect_flutter/views/brands.dart';
import 'package:vivanta_connect_flutter/views/loading.dart';
import 'package:vivanta_connect_flutter/views/privacy.dart';

class StartVivantaConnectWitkToken extends StatefulWidget {
  final String token;

  const StartVivantaConnectWitkToken({
    Key? key,
    required this.token,
  }) : super(key: key);

  @override
  State<StartVivantaConnectWitkToken> createState() =>
      _StartVivantaConnectWitkTokenState();
}

class _StartVivantaConnectWitkTokenState
    extends State<StartVivantaConnectWitkToken> {
  bool _loading = false;
  String _clientName = '';
  Client? _client;

  @override
  void initState() {
    _authenticate();
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    return _loading
        ? const Loading()
        : Scaffold(
            backgroundColor: VivantaColors.background,
            appBar: AppBar(
              backgroundColor: VivantaColors.background,
              elevation: 0,
              actions: [
                Padding(
                  padding: const EdgeInsets.only(right: 16),
                  child: GestureDetector(
                    onTap: () {
                      Navigator.of(context).pushReplacementNamed('/close');
                    },
                    child: const Icon(
                      Icons.close,
                      color: VivantaColors.text,
                      size: 24,
                    ),
                  ),
                ),
              ],
            ),
            body: Column(
              mainAxisAlignment: MainAxisAlignment.start,
              children: [
                const SizedBox(
                  height: 48,
                ),
                const Padding(
                  padding: EdgeInsets.symmetric(horizontal: 48),
                  child: Image(
                    image: AssetImage(
                      "images/vivanta-logo.png",
                      package: 'vivanta_connect_flutter',
                    ),
                    fit: BoxFit.cover,
                  ),
                ),
                const SizedBox(
                  height: 32,
                ),
                Padding(
                  padding: const EdgeInsets.symmetric(horizontal: 48),
                  child: RichText(
                    textAlign: TextAlign.center,
                    text: TextSpan(
                      children: [
                        TextSpan(
                          text: _clientName,
                          style: VivantaFonts.main
                              .copyWith(fontWeight: FontWeight.w700),
                        ),
                        const TextSpan(text: ' ', style: VivantaFonts.main),
                        TextSpan(
                          text: FlutterI18n.translate(context, "start.title"),
                          style: VivantaFonts.main,
                        ),
                      ],
                    ),
                  ),
                ),
                const SizedBox(
                  height: 32,
                ),
                Padding(
                  padding: const EdgeInsets.symmetric(horizontal: 48),
                  child: Row(
                    mainAxisAlignment: MainAxisAlignment.start,
                    crossAxisAlignment: CrossAxisAlignment.start,
                    children: [
                      Flexible(
                        child: Text(
                          FlutterI18n.translate(context, "start.message"),
                          maxLines: 2,
                          style: VivantaFonts.main,
                          softWrap: true,
                          textAlign: TextAlign.center,
                        ),
                      ),
                    ],
                  ),
                ),
              ],
            ),
            bottomNavigationBar: SizedBox(
              height: 160,
              child: Column(
                children: [
                  TextButton(
                    style: ButtonStyle(
                      backgroundColor: MaterialStateProperty.all<Color>(
                        VivantaColors.primary,
                      ),
                      fixedSize: MaterialStateProperty.all<Size>(
                        Size(MediaQuery.of(context).size.width - 48, 48),
                      ),
                    ),
                    onPressed: () {
                      Navigator.of(context).push(
                        MaterialPageRoute(
                          builder: (context) => Brands(client: _client),
                        ),
                      );
                    },
                    child: Text(
                      FlutterI18n.translate(context, "start.button"),
                      style: VivantaFonts.button,
                    ),
                  ),
                  const SizedBox(
                    height: 32,
                  ),
                  Padding(
                    padding: const EdgeInsets.symmetric(horizontal: 48),
                    child: RichText(
                      textAlign: TextAlign.center,
                      text: TextSpan(
                        children: [
                          TextSpan(
                            text:
                                FlutterI18n.translate(context, "start.legal1"),
                            style: VivantaFonts.privacy,
                          ),
                          const TextSpan(
                            text: " ",
                            style: VivantaFonts.privacy,
                          ),
                          TextSpan(
                            text:
                                FlutterI18n.translate(context, "start.legal2"),
                            style: VivantaFonts.privacy.copyWith(
                              fontWeight: FontWeight.w600,
                              decoration: TextDecoration.underline,
                            ),
                            recognizer: TapGestureRecognizer()
                              ..onTap = () {
                                Navigator.of(context).push(
                                  MaterialPageRoute(
                                    builder: (context) => const Privacy(),
                                  ),
                                );
                              },
                          ),
                          const TextSpan(
                            text: ".",
                            style: VivantaFonts.privacy,
                          ),
                        ],
                      ),
                    ),
                  ),
                ],
              ),
            ),
          );
  }

  Future<void> _authenticate() async {
    setState(() {
      _loading = true;
    });

    final result = await Http().getAuthenticatedUser(
      widget.token,
    );

    if (result != null) {
      final storage = Preferences();
      final externalCustomerId = result.externalId ?? '';
      storage.setCustomerId(externalCustomerId);
      storage.setExternalUserId(result.externalId ?? '');
      storage.setToken(widget.token);
      storage.setApiKey('');

      _client = result.client;

      setState(() {
        _loading = false;
        _clientName = result.client?.name ?? '';
      });

      return;
    }

    setState(() {
      _loading = false;
    });
  }
}
