import 'package:flutter/material.dart';

import 'package:webview_flutter/webview_flutter.dart';

import 'package:vivanta_connect_flutter/data/brand.dart';
import 'package:vivanta_connect_flutter/styles/colors.dart';
import 'package:vivanta_connect_flutter/styles/fonts.dart';
import 'package:vivanta_connect_flutter/views/loading.dart';

class Webview extends StatefulWidget {
  final Brand brand;
  final String url;

  const Webview({
    Key? key,
    required this.brand,
    required this.url,
  }) : super(key: key);

  @override
  State<Webview> createState() => _WebviewState();
}

class _WebviewState extends State<Webview> {
  late WebViewController _controller;
  bool _loading = false;

  @override
  void initState() {
    _controller = WebViewController()
      ..setJavaScriptMode(JavaScriptMode.unrestricted)
      ..clearLocalStorage()
      ..setBackgroundColor(VivantaColors.background)
      ..setNavigationDelegate(NavigationDelegate(
        onProgress: (progress) {
          setState(() {
            _loading = progress < 100;
          });
        },
        onPageStarted: (url) {},
        onPageFinished: (url) {
          setState(() {
            _loading = false;
          });
        },
        onWebResourceError: (WebResourceError error) {},
        onNavigationRequest: (NavigationRequest request) {
          return NavigationDecision.navigate;
        },
      ))
      ..loadRequest(Uri.parse(widget.url));
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    return _loading
        ? const Loading()
        : Scaffold(
            backgroundColor: VivantaColors.background,
            appBar: AppBar(
              backgroundColor: VivantaColors.background,
              elevation: 0,
              title: Text(
                "Connect your ${widget.brand.name} account",
                style: VivantaFonts.title,
              ),
              actions: [
                Padding(
                  padding: const EdgeInsets.only(right: 16),
                  child: GestureDetector(
                    onTap: () {
                      Navigator.of(context).pushReplacementNamed('/close');
                    },
                    child: const Icon(
                      Icons.close,
                      color: VivantaColors.text,
                      size: 24,
                    ),
                  ),
                ),
              ],
              leading: GestureDetector(
                onTap: () {
                  Navigator.of(context).maybePop();
                },
                child: const Icon(
                  Icons.arrow_back_ios,
                  color: VivantaColors.text,
                  size: 24,
                ),
              ),
            ),
            body: Column(
              children: [
                Expanded(
                  child: WebViewWidget(
                    controller: _controller,
                  ),
                ),
              ],
            ),
          );
  }
}
