import 'dart:developer';

import 'package:flutter/material.dart';

import 'package:flutter_i18n/flutter_i18n.dart';
import 'package:flutter_i18n/loaders/decoders/json_decode_strategy.dart';
import 'package:flutter_localizations/flutter_localizations.dart';

import 'package:vivanta_connect_flutter/screen_arguments.dart';
import 'package:vivanta_connect_flutter/views/close_vivanta_connect.dart';
import 'package:vivanta_connect_flutter/views/start_vivanta_connect.dart';
import 'package:vivanta_connect_flutter/views/start_vivanta_connect_with_token.dart';

class VivantaConnectFlutter extends StatefulWidget {
  const VivantaConnectFlutter({
    super.key,
    this.apiKey,
    this.customerId,
    this.externalUserId,
    this.companyId,
    this.token,
  });

  final String? apiKey;
  final String? customerId;
  final String? externalUserId;
  final String? companyId;
  final String? token;

  @override
  State<VivantaConnectFlutter> createState() => _VivantaConnectFlutterState();
}

class _VivantaConnectFlutterState extends State<VivantaConnectFlutter>
    with WidgetsBindingObserver {
  @override
  void initState() {
    super.initState();
    WidgetsBinding.instance.addObserver(this);
  }

  // This widget is the root of your application.
  @override
  Widget build(BuildContext context) {
    return MaterialApp(
      debugShowCheckedModeBanner: false,
      title: 'Vivanta Connect',
      routes: {
        '/': (context) => widget.token != null
            ? StartVivantaConnectWitkToken(token: widget.token!)
            : StartVivantaConnect(
                apiKey: widget.apiKey ?? '',
                customerId: widget.customerId ?? '',
                externalUserId: widget.externalUserId ?? '',
                companyId: widget.companyId,
              ),
        '/start': (context) => widget.token != null
            ? StartVivantaConnectWitkToken(token: widget.token!)
            : const StartVivantaConnect(
                apiKey: '',
                customerId: '',
                externalUserId: '',
              ),
        '/close': (context) => const CloseVivantaConnect(),
      },
      initialRoute: '/',
      onGenerateRoute: (settings) {
        final routeName = settings.name ?? '';
        if (routeName.contains('/start?')) {
          final stringParameters = routeName.replaceAll('/start?', '');
          final parameters = Uri.splitQueryString(stringParameters);

          final args = ScreenArguments(
            apiKey: parameters['apiKey'] ?? '',
            customerId: parameters['customerId'] ?? '',
            externalUserId: parameters['externalUserId'] ?? '',
            companyId: parameters['companyId'],
            token: parameters['token'],
          );

          return MaterialPageRoute(
            builder: (context) {
              if (args.token != null) {
                return StartVivantaConnectWitkToken(token: args.token!);
              }
              return StartVivantaConnect(
                key: const Key('vivanta-connect-from-route'),
                apiKey: args.apiKey,
                customerId: args.customerId,
                externalUserId: args.externalUserId,
                companyId: args.companyId,
              );
            },
          );
        }
        return null;
      },
      localizationsDelegates: [
        FlutterI18nDelegate(
          translationLoader: NetworkFileTranslationLoader(
            baseUri: Uri.https('vivanta-doc.s3.amazonaws.com', 'i18n'),
            fallbackFile: 'en',
            decodeStrategies: [JsonDecodeStrategy()],
          ),
          missingTranslationHandler: (key, locale) {
            log("--- Missing Key: $key, languageCode: ${locale?.languageCode}");
          },
        ),
        GlobalMaterialLocalizations.delegate,
        GlobalCupertinoLocalizations.delegate,
        GlobalWidgetsLocalizations.delegate
      ],
      supportedLocales: const [Locale('en'), Locale('es'), Locale('pt')],
    );
  }
}
